@@ -38,6 +38,20 @@ class AutoCodebaseDocumenter:
         # Load config from file
         self._load_config()
 
+    def _get_completion(self, prompt):
+        return self._openai_chat_completion_create(prompt)
+
+    def _openai_chat_completion_create(self, prompt):
+        # This is where you actually call the openai API
+        response = openai.ChatCompletion.create(
+            model="text-davinci-002",
+            messages=[
+                {"role": "system", "content": "You are a helpful assistant."},
+                {"role": "user", "content": prompt},
+            ],
+        )
+        return response.choices[0].message["content"]
+
     def _setup_logging(self):
         log_level = logging.DEBUG if self.debug else logging.INFO
         logging.basicConfig(level=log_level)
